Imports System.Data
Imports System.Data.OleDb
Public Class frmPublishers
  Dim BooksConnection As OleDbConnection
  Dim PublishersCommand As OleDbCommand
  Dim PublishersAdapter As OleDbDataAdapter
  Dim PublishersTable As DataTable
  Dim PublishersManager As CurrencyManager

  Private Sub frmPublishers_FormClosing(ByVal sender As Object, ByVal e As System.Windows.Forms.FormClosingEventArgs) Handles Me.FormClosing
    'close the connection
    BooksConnection.Close()
    'dispose of the objects
    BooksConnection.Dispose()
    PublishersCommand.Dispose()
    PublishersAdapter.Dispose()
    PublishersTable.Dispose()
  End Sub

  Private Sub frmPublishers_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
    Try
      'point to help file
      hlpPublishers.HelpNamespace = Application.StartupPath + "\publishers.chm"
      'connect to books database
      BooksConnection = New OleDbConnection("Provider=Microsoft.Jet.OLEDB.4.0; Data Source = c:\VB2005DB\Working\books.mdb")
      BooksConnection.Open()
      'establish command object
      PublishersCommand = New OleDbCommand("Select * from Publishers ORDER BY Name", BooksConnection)
      'establish data adapter/data table
      PublishersAdapter = New OleDbDataAdapter()
      PublishersAdapter.SelectCommand = PublishersCommand
      PublishersTable = New DataTable()
      PublishersAdapter.Fill(PublishersTable)
      'bind controls to data table
      txtPubID.DataBindings.Add("Text", PublishersTable, "PubID")
      txtPubName.DataBindings.Add("Text", PublishersTable, "Name")
      txtCompanyName.DataBindings.Add("Text", PublishersTable, "Company_Name")
      txtPubAddress.DataBindings.Add("Text", PublishersTable, "Address")
      txtPubCity.DataBindings.Add("Text", PublishersTable, "City")
      txtPubState.DataBindings.Add("Text", PublishersTable, "State")
      txtPubZip.DataBindings.Add("Text", PublishersTable, "Zip")
      txtPubTelephone.DataBindings.Add("Text", PublishersTable, "Telephone")
      txtPubFAX.DataBindings.Add("Text", PublishersTable, "FAX")
      txtPubComments.DataBindings.Add("Text", PublishersTable, "Comments")
      'establish currency manager
      PublishersManager = DirectCast(Me.BindingContext(PublishersTable), CurrencyManager)
    Catch ex As Exception
      MessageBox.Show(ex.Message, "Error establishing Publishers table.", MessageBoxButtons.OK, MessageBoxIcon.Error)
      Exit Sub
    End Try
    Me.Show()
    Call SetState("View")
  End Sub

  Private Sub btnPrevious_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnPrevious.Click
    If PublishersManager.Position = 0 Then Console.Beep()
    PublishersManager.Position -= 1
  End Sub

  Private Sub btnNext_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnNext.Click
    If PublishersManager.Position = PublishersManager.Count - 1 Then Console.Beep()
    PublishersManager.Position += 1
  End Sub

  Private Sub btnSave_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnSave.Click
    If Not (ValidateData()) Then Exit Sub
    Try
      MessageBox.Show("Record saved.", "Save", MessageBoxButtons.OK, MessageBoxIcon.Information)
      Call SetState("View")
    Catch ex As Exception
      MessageBox.Show("Error saving record.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
    End Try
  End Sub

  Private Sub btnDelete_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnDelete.Click
    Dim Response As Windows.Forms.DialogResult
    Response = MessageBox.Show("Are you sure you want to delete this record?", "Delete", MessageBoxButtons.YesNo, MessageBoxIcon.Question, MessageBoxDefaultButton.Button2)
    If Response = Windows.Forms.DialogResult.No Then
      Exit Sub
    End If
    Try
    Catch ex As Exception
      MessageBox.Show("Error deleting record.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
    End Try
  End Sub
  Private Sub SetState(ByVal AppState As String)
    Select Case AppState
      Case "View"
        txtPubID.BackColor = Color.White
        txtPubID.ForeColor = Color.Black
        txtPubName.ReadOnly = True
        txtCompanyName.ReadOnly = True
        txtPubAddress.ReadOnly = True
        txtPubCity.ReadOnly = True
        txtPubState.ReadOnly = True
        txtPubZip.ReadOnly = True
        txtPubTelephone.ReadOnly = True
        txtPubFAX.ReadOnly = True
        txtPubComments.ReadOnly = True
        btnPrevious.Enabled = True
        btnNext.Enabled = True
        btnAddNew.Enabled = True
        btnSave.Enabled = False
        btnCancel.Enabled = False
        btnEdit.Enabled = True
        btnDelete.Enabled = True
        btnDone.Enabled = True
        txtPubName.Focus()
      Case "Add", "Edit"
        txtPubID.BackColor = Color.Red
        txtPubID.ForeColor = Color.White
        txtPubName.ReadOnly = False
        txtCompanyName.ReadOnly = False
        txtPubAddress.ReadOnly = False
        txtPubCity.ReadOnly = False
        txtPubState.ReadOnly = False
        txtPubZip.ReadOnly = False
        txtPubTelephone.ReadOnly = False
        txtPubFAX.ReadOnly = False
        txtPubComments.ReadOnly = False
        btnPrevious.Enabled = False
        btnNext.Enabled = False
        btnAddNew.Enabled = False
        btnSave.Enabled = True
        btnCancel.Enabled = True
        btnEdit.Enabled = False
        btnDelete.Enabled = False
        btnDone.Enabled = False
        txtPubName.Focus()
    End Select
  End Sub

  Private Sub btnAddNew_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnAddNew.Click
    Try
      Call SetState("Add")
    Catch ex As Exception
      MessageBox.Show("Error adding record.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
    End Try
  End Sub

  Private Sub btnEdit_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnEdit.Click
    Call SetState("Edit")
  End Sub

  Private Sub btnCancel_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnCancel.Click
    Call SetState("View")
  End Sub



  Private Function ValidateData() As Boolean
    Dim Message As String = ""
    Dim AllOK As Boolean = True
    'Check for name
    If txtPubName.Text.Trim = "" Then
      Message = "You must enter an Publisher Name." + ControlChars.CrLf
      txtPubName.Focus()
      AllOK = False
    End If
    If Not (AllOK) Then
      MessageBox.Show(Message, "Validation Error", MessageBoxButtons.OK, MessageBoxIcon.Information)
    End If
    Return (AllOK)
  End Function



  Private Sub btnHelp_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnHelp.Click
    Help.ShowHelp(Me, hlpPublishers.HelpNamespace)
  End Sub

  Private Sub txtInput_KeyPress(ByVal sender As System.Object, ByVal e As System.Windows.Forms.KeyPressEventArgs) Handles txtPubName.KeyPress, txtPubZip.KeyPress, txtPubTelephone.KeyPress, txtPubState.KeyPress, txtPubFAX.KeyPress, txtPubComments.KeyPress, txtPubCity.KeyPress, txtPubAddress.KeyPress, txtCompanyName.KeyPress
    Dim WhichBox As TextBox = CType(sender, TextBox)
    If e.KeyChar = ControlChars.Cr Then
      Select Case WhichBox.Name
        Case "txtPubName"
          txtCompanyName.Focus()
        Case "txtCompanyName"
          txtPubAddress.Focus()
        Case "txtPubAddress"
          txtPubCity.Focus()
        Case "txtPubCity"
          txtPubState.Focus()
        Case "txtPubState"
          txtPubZip.Focus()
        Case "txtPubZip"
          txtPubTelephone.Focus()
        Case "txtPubTelephone"
          txtPubFAX.Focus()
        Case "txtPubFAX"
          txtPubComments.Focus()
        Case "txtPubComments"
          txtPubName.Focus()
      End Select
    End If
  End Sub
End Class
